sendmail <- function(path, filename, to, cc = NULL, bcc = NULL,
                     f, replyto = NULL, subject, body = NULL,
                     port, server, u, pw,
                     attach = NULL,
                     log = NULL,
                     wait = TRUE) {

    rmsp <- function (s) {
        s <- gsub("^\\s*", "", s)
        gsub("\\s*$", "", s)
    }
    rmspa <- function (s)
        gsub("\\s*", "", s)

    clps <- function(s)
        paste(s, sep = "", collapse = ",")

    checkNull <- function(s, within = FALSE, quote = FALSE) {
        if (!is.null(s) && !(s == ""))
            if (within)
                paste("-", substitute(s), " ", clps(rmspa(s)), sep = "")
            else
                paste("-", substitute(s), " ", clps(rmsp(s)), sep = "")
        else
            s
    }

    path <- normalizePath(path)
    if (missing(filename)) {
        filename <- "-"
        if (is.null(body) || body == "")
            body <- "|"
    } else {
        filename <- normalizePath(filename)
        body <- NULL
    }
    if (!is.null(log))
        log <- paste("-log", suppressWarnings(normalizePath(log)))

    if (!is.null(attach) && !(attach  == "")) {
        if (any(grepl(",", attach))) {
            attach <- rmsp(unlist(strsplit(attach, ",")))
            attach <- normalizePath(attach)
        }
        attach <- dQuote(attach)
        attach <- paste("-attach", clps(attach))
    }
    cc <- checkNull(cc, TRUE)
    bcc <- checkNull(bcc, TRUE)
    replyto <- checkNull(replyto, TRUE)

    str <- paste(rmsp(path),
                 rmsp(filename),
                 "-to", clps(rmsp(to)),
                 cc,
                 bcc,
                 replyto,
                 "-f", rmsp(f) ,
                 "-port", port,
                 "-subject", dQuote(subject),
                 ifelse(is.null(body), "", paste("-body", dQuote(body))),
                 "-server", server,
                 "-u", u,
                 "-pw", pw,
                 attach,
                 log)
    system(str)
}
